@@ -2,26 +2,13 @@
 
 import sys, re, traceback
 from ..abstract import AbstractReader
-from .timeutils import *
+from ..utils import *
+
 try:
     import pymysql as mariadb
 except:
     import MySQLdb as mariadb
-       
-       
-# Utilities
 
-def _translate(model):
-    model = str(model).lower().replace('.*','*').replace('*','%')
-    if ':' not in model:
-        model = '%/' + model
-    return model
-
-def _match(pattern, model):
-    if '*' in pattern and '.*' not in pattern:
-        pattern = pattern.replace('*','.*')
-    return re.match('^%s$' % pattern.lower().replace('%','.*'), model)
-            
 # MariaDBReader
 
 class MariaDBReader(AbstractReader):
@@ -93,6 +80,14 @@ class MariaDBReader(AbstractReader):
         self.password = self.config.get('password','')
         self.port = int(self.config.get('port','3306'))
         self.host = self.config.get('host','localhost')
+        self.decimate = self.config.get('decimate',None)
+        if self.decimate:
+            if re.match('[0-9]+',decimate):
+                self.decimate = int(self.decimate)
+            elif str(self.decimate).lower().strip() == 'false':
+                self.decimate = False
+            elif str(self.decimate).lower().strip() in ('true','yes'):              
+                decimate = True # decimation chosen by api
 
         self.attributes = {}
         self.tables = {} #table creators
@@ -178,7 +173,7 @@ class MariaDBReader(AbstractReader):
             self.get_attribute_id_table('*')
             
         if pattern:
-            return [a for a in self.attributes if _match(pattern,a)]
+            return [a for a in self.attributes if attr_match(pattern,a)]
             
         return self.attributes.keys()
     
@@ -186,7 +181,7 @@ class MariaDBReader(AbstractReader):
         """
         get attribute name as it is used in hdb++ (e.g. FQDN)
         """
-        attribute = _translate(attribute)
+        attribute = attr_translate(attribute)
         attrs = self.get_attributes(pattern=attribute, load=False)
         if len(attrs)>1:
             raise Exception('MultipleAttributeMatches')
@@ -278,6 +273,7 @@ class MariaDBReader(AbstractReader):
             (epoch1, r_value, w_value, quality, error_desc),
             ... ]
         """
+        decimate = self.decimate if decimate is None else decimate
         attribute = self.get_attribute_name(attribute)
         r = self.get_attributes_values([attribute], start_date, stop_date, 
                                        decimate, False, **params)
