@@ -9,8 +9,7 @@ import importlib
 import collections.abc
 import traceback
 
-
-logger = logging.getLogger('hdbpp_reader')
+from .utils import load_config_from_tango, logger, parse_config_string
 
 ###############################################################################
 
@@ -40,10 +39,19 @@ Options (at least some is needed):
 
 """
 
-get_hdb_property = lambda p: tangodb.get_property('HDB++',p)[p]
 
 def get_default_reader(tango_host=''):
     try:
+        schema = os.getenv('DEFAULT_READER',None)
+        logger.info('get_default_reader(%s)' % (schema))
+        if schema:
+            logger.info('os://DefaultSchema: %s' % str(schema))
+            if'@' not in schema:
+                schema = load_config_from_tango(schema)
+                return reader(apiclass=schema['apiclass'],config=schema['config'])
+            else:
+                return reader(config=schema)
+
         import tango
         if tango_host:
             tangodb = tango.Database(*tango_host.split(':'))
@@ -52,14 +60,15 @@ def get_default_reader(tango_host=''):
 
         schema = tangodb.get_property('HDB++','DefaultSchema'
                         )['DefaultSchema'][0]        
+        logger.info('tango://DefaultSchema: %s' % str(schema))
         data = load_config_from_tango(schema)
-        return reader(apiclass=data['apiclass'],config=data['config'])
+        return reader(apiclass=data['apiclass'],config=data)
     
     except:
         logger.warning(traceback.format_exc())
         logger.warning('get_default_reader: unable to get Tango DB(%s)'
                        % tango_host,
-                       exc_info=logger.level==logging.DEBUG)
+                       exc_info=(logger.level==logging.DEBUG))
         
 
     
@@ -68,7 +77,13 @@ def reader(apiclass='pyhdbpp.abstract.AbstractReader', config=None):
     Initialize a reader object, based on the specified backend
     and a config dictionnary.
     """
-    #print('Creating pyhdbpp.reader(%s)' % config)
+    logger.info('Creating pyhdbpp.reader(%s,%s)' % (apiclass,config))
+    
+    apiclass = config.get('apiclass',apiclass)
+    mod_name, class_name = apiclass.rsplit('.', 1)
+    module = importlib.import_module(mod_name)        
+    apiclass = getattr(module, class_name)
+    
     if not config:
         return get_default_reader()
 
@@ -81,15 +96,13 @@ def reader(apiclass='pyhdbpp.abstract.AbstractReader', config=None):
         elif config:
             config = parse_config_string(config)
             
+        print(config)
+        
         if not validate_config(config):
             logger.error(config)
             raise Exception('InvalidConfig')
-
-    apiclass = config.pop('apiclass',apiclass)
-    mod_name, class_name = apiclass.rsplit('.', 1)
-    module = importlib.import_module(mod_name)        
-
-    return getattr(module, class_name)(**config)
+    
+    return apiclass(**config)
 
 def load_config_from_file(config_file):
     """
@@ -118,78 +131,6 @@ def load_config_from_file(config_file):
         logger.error(traceback.format_exc())
         return None
     
-def load_config_from_tango(schema, root = 'HDB++', tango_host = ''):
-    """
-    Load config from TangoDB using tango://ObjectName.PropertyName
-    Current version only accept Tango Free Properties
-    """
-    try:
-        logger.debug('load_config_from_tango(%s)' % schema)
-        schema = str(schema).replace('tango:','').strip('/')
-        if '.' in schema:
-            root,schema = schema.rsplit('.',1)
-        if ':' in root:
-            tango_host, root = schema.split('/')
-            
-        import tango
-        if tango_host:
-            tangodb = tango.Database(*tango_host.split(':'))
-        else:
-            tangodb = tango.Database()            
-    
-        get_hdb_property = lambda p: tangodb.get_property(root,p)[p]
-        config = dict(str(l).split('=') for l in get_hdb_property(schema) 
-                      if '=' in l)
-        if '@' in config.get('config',''):
-            config.update(parse_config_string(config['config']))
-
-        # fill missing fields
-        config['database'] = config.get('database',
-                            config.get('db_name',
-                           config.get('dbname','hdbpp')))
-        config['password'] = config.get('password',
-                            config.get('passwd',
-                           config.get('token','')))
-        config['config'] = config.get('config', '%s:%s@%s:%s/%s' % (
-            config['user'], config['password'], config['host'],
-            config.get('port','3306'), config.get('database')))
-                
-        return config
-    
-    except Exception as e:
-        logger.error(traceback.format_exc())
-        return None
-
-def parse_config_string(connect_str):
-    """
-    Parse a connect string into the various element to initiate a connection.
-    Arguments:
-        connect_str : str -- user:password@host:port/database
-    Returns:
-        dict -- dictionary of values from the connect string.
-    """
-    config = {}
-    if not any(c in connect_str for c in '@:/'):
-        # Unparsable string, check tango properties
-        config =  load_config_from_tango(connect_str)
-    
-    if not config:
-        try:
-            logger.debug('parse_config_str(%s)' % connect_str)
-            config_split, config['database'] = connect_str.split('/')
-            user_pass, host_port = config_split.split('@')
-            i = user_pass.find(':')
-            config['user'] = user_pass[:i]
-            config['password'] = user_pass[i+1:]
-            j = host_port.find(':')
-            config['host'] = host_port[:j]
-            config['port'] = host_port[j+1:]
-        
-        except Exception as e:
-            logger.debug(traceback.print_exc())
-            logger.error(str(e))
-   
-    return config or None
 
 def add_defaults_to_config(config):
     """
@@ -288,11 +229,6 @@ def main():
 
     args = parser.parse_args()
 
-    stdout_formatter = logging.Formatter("%(asctime)s hdbpp_reader[%(process)d]: %(message)s", "%Y-%m-%d %H:%M:%S")
-    stdout_handler = logging.StreamHandler()
-    stdout_handler.setFormatter(stdout_formatter)
-    logger.addHandler(stdout_handler)
-
     if args.syslog:
         syslog_formatter = logging.Formatter("hdbpp_reader[%(process)d]: %(message)s")
         syslog_handler = logging.handlers.SysLogHandler(address='/dev/log')
